#
# spec file for package sbctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sbctl
Version:        0.14
Release:        1.1
Summary:        Secure Boot key manager
License:        MIT
Group:          System/Boot
URL:            https://github.com/Foxboron/sbctl
%if "%{_vendor}" == "debbuild"
# Needed to set Maintainer in output debs
Packager:       Jan Loeser <jan.loeser@posteo.de>
%endif
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        %{name}-rpmlintrc
Requires:       binutils
%if 0%{?suse_version}
Requires:       util-linux-systemd
%endif
%if 0%{?ubuntu}
Requires:       util-linux
%endif
BuildRequires:  asciidoc
BuildRequires:  binutils
%if 0%{?suse_version}
BuildRequires:  golang-packaging
%endif
%if 0%{?ubuntu}
BuildRequires:  golang
%endif

%description
sbctl intends to be a user-friendly secure boot key manager capable of setting
up secure boot, offer key management capabilities, and keep track of files that
needs to be signed in the boot chain.

%prep
%autosetup -a 1

%build
%make_build all

%install
%make_install BINDIR="%{_sbindir}" PREFIX="%{_prefix}"

# Fix potential-bashisms rpmlint error by using bash shebang
sed -i 's|bin/sh|bin/bash|' %{buildroot}%{_prefix}/lib/kernel/install.d/91-sbctl.install

%check
%make_build test

%files
%doc README.md
%license LICENSE

%dir %{_prefix}/lib/kernel/
%dir %{_prefix}/lib/kernel/install.d/
%dir %{_datadir}/fish/
%dir %{_datadir}/fish/vendor_completions.d/
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions/

%{_prefix}/lib/kernel/install.d/91-sbctl.install
%{_mandir}/man8/sbctl.8*
%{_datadir}/bash-completion/completions/sbctl
%{_datadir}/fish/vendor_completions.d/sbctl.fish
%{_datadir}/zsh/site-functions/_sbctl
%{_sbindir}/sbctl

%changelog
* Thu May  9 2024 Joshua Smith <smolsheep@opensuse.org>
- Enable tests
- Fix bashism error in 91-sbctl.install by using bash shebang
- Service to use manual instead of deprecated disabled and pattern
  cleanup
- Update to version 0.14:
  New commands
  * export-enrolled-keys will export all enrolled keys on the
    system to a directory
  * list-enrolled-keys will list the enrolled keys on the system
  New Things
  * The test suite has now been rewritten to use the new vmtest
    library.
  Bugfixes
  * sign-all won't abort when it encounters a file it can't sign.
  * The kernel-install hook won't try to sign things if there are
    no signing keys available.
  * The kernel-install hook will now only remove things if they
    actually did exist on the system.
  * The mkinitcpio hook now only sign the built kernel/UKI instead
    of all the sbctl files.
* Wed Dec 27 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.13:
  * --export,-e and --database-path,-d now work properly and don't
    overwrite the create-keys variables internally
  * remove erronous dbx enrollment. Previous release implemented
    support for dbx that doesn't really work as expected. It
    would also fail to enroll keys for previously setup clients.
    Implementation has been removed and will be iterated upon at a
    later date.
  * make: fix github artifact upload
  * Change shebang
  * Ensure file signing hook is run when initrd is rebuilt
  * Fixed typo, removed mention enroll-keys enables Secure Boot
    automatically
  * Ignore Setup mode and immutable variables for export
  * Specify file origin + always print signing message
  * tests/utils/certs.go: drop keyUsage bitfield
  * update manpage docs
  * allow specifying keys and GUID paths
  * Update README.md
  * keys.go: drop the keyUsage bitfield
  * Check and return Open errs
  * Update documentation for custom dbx
* Fri Oct 20 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.12:
  * sbctl bundle might be depreciated in the future.
  * sbctl now allows you to enroll custom certificates into KEK
    and db.
  * sbctl now allows keys to be exported as EFI Signature Lists
    (esl) or EFI Authenticated Variables (auth), which are pre-signed.
  * sbctl can now enroll certificates found in dbxDefault,
    dbDefault, KEKDefault and PKDefault.
  * Before this release sbctl would enroll, reset and rotate the
    entire key hierarchy when requested. With this release several
    improvements have been made to have the ability to support
    partial key hierarchies. This can be used through the --partial
    flag in their respective commands.
  * add documentation for the extra flags of enroll/rotate/reset
  * feat: add option to remove specific certs from db instead of an entire reset
  * feat: add append option to enroll-keys
  * feat: force key flag
  * Add support for OEM dbx enrollment
  * feat(dbx): enroll/rotate/reset dbx keys
  * feat(rotate): enable partial rotation and providing different sources
  * feat(reset): enable partial resets of secureboot keys
  * feat(enroll-keys): add partial enrollment of keys
  * Implement full support for loading builtin firmware certificates
  * Add support for loading certificates from dbDefault
* Mon Mar 27 2023 jan.loeser@posteo.de
- Update to version 0.11:
  * status: Warn about firmware quirks
  * Add trailing newline to JSON output
  * Improve wording
  * Always include vendor keys in status output
  * Move a few more functions to afero and fs.Fs
  * Remove unused code
  * Include fs module
  * Implement fs package and remove all direct filesystem calls
  * Updated dependencies
  * status: Added e2e test
  * enroll-keys: remove variable overriding for OEM key enrollment
  * updated to go 1.20
  * Fix arbitrary sizes in UKI generation
  * Update README.md
  * enroll-keys: Enroll Microsoft KEK along with their other keys
  * pacman: Add extramodules target to hook
  * Fix POSIX sh comparison
  * verify: Implement file verification
* Thu Jan 19 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.10:
  * go.mod: Properly fetch new library version
  * go.mod: update go-uefi and cleanup
  * rotate-keys: Implement rotate-keys
  * Add support for the uki layout
  * Fix typos and some improve grammar a bit
  * sbctl.8: Provide more precise setup mode instructions
  * enroll-keys: Error if user has Setup Mode disabled
  * update manpage to reflect defaults in bundle.go
  * Fix crash when ESP is not mounted
  * main: Always ensure we allow printing before json prints
* Mon Nov 28 2022 Joshua Smith <jsmithfpv@gmail.com>
- Initial package of sbctl 0.9.0 for openSUSE
